@@ -25,6 +25,7 @@ import android.os.SystemClock;
 import android.support.v4.media.session.MediaButtonReceiver;
 import android.view.KeyEvent;
 
+import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Util;
 
@@ -113,6 +114,7 @@ public class RemoteControlClientReceiver extends MediaButtonReceiver {
             context.startService(intent);
             return;
         }
-        super.onReceive(context, intent);
+        if (!AndroidUtil.isOOrLater) //We need AppCompat 26+ for Oreo service management
+            super.onReceive(context, intent);
     }
 }
