@@ -93,12 +93,13 @@ public abstract class BaseAudioBrowser extends SortableFragment<AudioBrowserAdap
 
     @Override
     public boolean onPrepareActionMode(ActionMode mode, Menu menu) {
-        int count = getCurrentAdapter().getSelectionCount();
+        final List<MediaLibraryItem> selection = getCurrentAdapter().getSelection();
+        final int count = selection.size();
         if (count == 0) {
             stopActionMode();
             return false;
         }
-        boolean isSong = count == 1 && getCurrentAdapter().getSelection().get(0).getItemType() == MediaLibraryItem.TYPE_MEDIA;
+        boolean isSong = count == 1 && selection.get(0).getItemType() == MediaLibraryItem.TYPE_MEDIA;
         menu.findItem(R.id.action_mode_audio_set_song).setVisible(isSong && AndroidDevices.isPhone);
         menu.findItem(R.id.action_mode_audio_info).setVisible(count == 1);
         menu.findItem(R.id.action_mode_audio_append).setVisible(mService.hasMedia());
