@@ -59,6 +59,7 @@ public class AndroidDevices {
     public final static boolean hasNavBar;
     public final static boolean hasTsp;
     public final static boolean isAndroidTv;
+    public final static boolean isAmazon = TextUtils.equals(Build.MANUFACTURER,"Amazon");
     public final static boolean isChromeBook;
     public static final boolean hasPiP;
     public final static boolean showInternalStorage = !TextUtils.equals(Build.BRAND, "Swisscom") && !TextUtils.equals(Build.BOARD, "sprint");
@@ -103,8 +104,8 @@ public class AndroidDevices {
         isChromeBook = pm != null && pm.hasSystemFeature("org.chromium.arc.device_management");
         hasPlayServices = pm == null || hasPlayServices(pm);
         hasPiP = AndroidUtil.isOOrLater || AndroidUtil.isNougatOrLater && isAndroidTv;
-        isPhone = ctx == null || ((TelephonyManager) ctx.getSystemService(Context.TELEPHONY_SERVICE))
-                .getPhoneType() != TelephonyManager.PHONE_TYPE_NONE;
+        final TelephonyManager tm = ctx != null ? ((TelephonyManager) ctx.getSystemService(Context.TELEPHONY_SERVICE)) : null;
+        isPhone = tm == null || tm.getPhoneType() != TelephonyManager.PHONE_TYPE_NONE;
         // hasCombBar test if device has Combined Bar : only for tablet with Honeycomb or ICS
         hasCombBar = !AndroidDevices.isPhone && AndroidUtil.isHoneycombOrLater
                 && !AndroidUtil.isJellyBeanMR1OrLater;
@@ -129,7 +130,7 @@ public class AndroidDevices {
                 final StringTokenizer tokens = new StringTokenizer(line, " ");
                 final String device = tokens.nextToken();
                 final String mountpoint = tokens.nextToken();
-                final String type = tokens.nextToken();
+                final String type = tokens.hasMoreTokens() ? tokens.nextToken() : null;
 
                 // skip if already in list or if type/mountpoint is blacklisted
                 if (list.contains(mountpoint) || typeBL.contains(type) || Strings.startsWith(mountBL, mountpoint))
